@@ -452,10 +452,17 @@ class Pypher(with_metaclass(_Link)):
 
         return self
 
-    def append(self, *pyphers):
-        for p in pyphers:
-            self.next = p.next
-            self._bottom = p._bottom
+    def append(self, pypher):
+        token = self.next
+
+        while token:
+            try:
+                token.next.next
+                token = token.next
+            except Exception as e:
+                token.next = pypher.next
+                self._bottom = pypher.next
+                break
 
         return self
 
